@@ -1,5 +1,8 @@
+from utils import logs
+
 def main():
     print('model was trained')
+    logs.log_data()
 
 if __name__=='__main__':
     main()
